<?php
namespace Ep\Gath\Hydrator;

use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\Hydrator\NamingStrategy\MapNamingStrategy;
use Zend\Hydrator\Reflection as ReflectionHydrator;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu hidratora za stanje zalihe.
 *
 * @package Ep\Gath\Hydrator
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class StockHydratorFactory implements FactoryInterface
{
	/**
	 * Stvara objekt
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		$hydrator = new ReflectionHydrator();

		$hydrator->setNamingStrategy(new MapNamingStrategy([
			'ProductCode' => 'sku',
			'Stock' => 'stock',
		]));

		return $hydrator;
	}
}