<?php
namespace Ep\Gath\WordPress;

use Ep\Gath\Entity\Stock;
use Ep\Gath\Exception;
use Ep\Gath\GathService;

/**
 * Pruža podatke o stanju zalihe proizvodima.
 *
 * @package Ep\Gath\WordPress
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class StockProvider extends ProductMetadataProvider
{
	/** @var array */
	protected $metaKeys = [
		'_manage_stock',
		'_stock',
		'_stock_status',
	];

	/**
	 * Učitava cijene i zalihu za date proizvode.
	 */
	public function loadMetadata(): void
	{
		try {
			if (count($this->preload) > 0) {
				$stocks = $this->gath->getProductStock(array_values($this->preload));

				foreach ($stocks as $stock) {
					if ($postId = array_search($stock->getSku(), $this->preload)) {
						$this->loaded[$postId] = $stock;
					} /*else {
						throw new Exception\MetadataException('Dobio sam podatke proizvoda koje nisam tražio.');
					}*/
				}
			}
		} catch (Exception\ExceptionInterface $e) {
			throw new Exception\MetadataException('Došlo je do nekakve greške s Gathom.', 0, $e);
		}
	}

	/**
	 * Vraća stanje zalihe za dati proizvod.
	 *
	 * @param int $postId
	 *
	 * @return Stock|null
	 */
	protected function getStock(int $postId): ?Stock
	{
		if ($postId > GathService::PRODUCT_ID_OFFSET) {
			$postId -= GathService::PRODUCT_ID_OFFSET;
		}

		if (!isset($this->loaded[$postId])) {
			$this->preloadMetadata([$postId]);
		}

		return $this->loaded[$postId] ?? null;
	}

	/**
	 * Vraća vrijednost metapodatka iz nekog drugog izvora, ovisno o implementaciji.
	 *
	 * @param int $postId
	 * @param string $metaKey
	 *
	 * @param mixed|null $metaValue
	 *
	 * @return mixed
	 */
	public function getMetadata(int $postId, string $metaKey, $metaValue = null)
	{
		/*if ($postId > GathService::PRODUCT_ID_OFFSET) {
			$postId -= GathService::PRODUCT_ID_OFFSET;
		}*/

		if (!$this->getStock($postId)) {
			$this->load();
		}

		if (!in_array($metaKey, $this->metaKeys)) {
			return null;
		}

		$stock = $this->getStock($postId);

//		var_dump($postId, $stock);

		$stockAmount = 0;
		$stockStatus = 'outofstock';

		if (null === $stock) {
			// Za grupirane proizvode nemamo Stock objekt, ali želimo stanje takvog
			// proizvoda zasnovati na stanju djece.
			$childIds = get_post_meta($postId, '_children', true);

			if (is_array($childIds) && count($childIds) > 0) {
				foreach ($childIds as $childId) {
					if ($childStock = $this->getStock($childId)) {
						$stockAmount += $childStock->getStock();
					}
				}
			}

			if ($stockAmount > 0) {
				$stockStatus = 'instock';
			}
		} else {
			$stockAmount = $stock->getStock();
			$stockStatus = $stock->getStock() > 0 ? 'instock' : 'outofstock';
		}

		switch ($metaKey) {
			case '_manage_stock':
				return 'yes';
			case '_stock':
				return $stockAmount;
			case '_stock_status':
				return $stockStatus;
		}

		return '';
	}
}