<?php
namespace Ep\Google\Validator;

use Ep\Http\Service\HttpClientManager;
use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class ReCaptchaFactory
 *
 * @package Ep\Google\Validator
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class ReCaptchaFactory implements FactoryInterface
{
	/**
	 * Create an object
	 *
	 * @param  ContainerInterface $container
	 * @param  string $requestedName
	 * @param  null|array $options
	 *
	 * @return object
	 * @throws ServiceNotFoundException if unable to resolve the service.
	 * @throws ServiceNotCreatedException if an exception is raised when
	 *     creating a service.
	 * @throws ContainerException if any other error occurs
	 */
	public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
	{
		/** @var HttpClientManager $httpClients */
		$httpClients = $container->get('HttpClientManager');
		$client = $httpClients->get('recaptcha');
		$config = $container->get('config')['recaptcha'];

		$validator = new ReCaptcha($options);
		$validator->setHttpClient($client);
		$validator->setSecretKey($config['secret_key']);

		return $validator;
	}
}