<?php
namespace Ep\WooCommerce;

use Ep\WordPress\Service\AbstractWordPressService;

/**
 * Briše stvari 'iz WooCommerca'.
 *
 * @package Ep\WooCommerce
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class WooCommerceRemover extends AbstractWordPressService
{
	/**
	 * Dodaje handlere na WP akcije i filtere.
	 */
	public function attach(): void
	{
		add_action('admin_menu', [$this, 'addMenuItem']);
	}

	/**
	 * Izvršava se prilikom inicijalizacije admina.
	 */
	public function attachAdmin(): void
	{
		if ('POST' === $_SERVER['REQUEST_METHOD'] && isset($_POST['submit']) && 'ep-woocommerce-remover' === $_POST['submit']) {
			$this->process();
		}
	}

	/**
	 * Dodaje stavku u izbornik.
	 */
	public function addMenuItem(): void
	{
		add_menu_page(
			'WooCommerce Remover',
			'WooCommerce Remover',
			'manage_options',
			'ep-product-remover',
			[$this, 'renderPage'],
			'dashicons-trash'
		);
	}

	/**
	 * Renderira stranicu.
	 */
	public function renderPage()
	{
		echo $this->getView()->render('admin/woocommerce-remover.twig', [
			'page_title' => get_admin_page_title(),
		]);
	}

	/**
	 * Odrađuje što već treba.
	 */
	protected function process()
	{
		if (isset($_POST['removeProducts']) && '1' === $_POST['removeProducts']) {
			$this->deleteProducts();
		}

		if (isset($_POST['removeCategories']) && '1' === $_POST['removeCategories']) {
			$this->deleteCategories();
		}

		if (isset($_POST['removeBrands']) && '1' === $_POST['removeBrands']) {
			$this->deleteTaxonomy('product_brand');
		}

		if (isset($_POST['removeShippingClasses']) && '1' === $_POST['removeShippingClasses']) {
			$this->deleteTaxonomy('product_shipping_class');
		}
	}

	/**
	 * Briše sve proizvode.
	 */
	protected function deleteProducts()
	{
		global $wpdb;

		$sql = "SELECT `ID` FROM `{$wpdb->prefix}posts` WHERE `post_type` = 'product'";

		if (isset($_POST['product_date_from']) && strlen($_POST['product_date_from']) > 0) {
			$date = date('Y-m-d', strtotime($_POST['product_date_from']));
			if ($date !== $_POST['product_date_from']) {
				wp_die('Neispravan datum!');
			}

			$sql .= ' AND `post_date` > "' . $date . '"';
		}

		$productIds = $wpdb->get_col($sql, 0);

		foreach ($productIds as $productId) {
			set_time_limit(0);
			$productId = intval($productId);

			if ($thumbnailId = get_post_meta($productId, '_thumbnail_id', true)) {
				wp_delete_attachment($thumbnailId, true);
			}

			if ($gallery = get_post_meta($productId, '_product_image_gallery', true)) {
				$galleryImageIds = explode(',', $gallery);

				foreach ($galleryImageIds as $galleryImageId) {
					$galleryImageId = intval($galleryImageId);
					wp_delete_attachment($galleryImageId, true);
				}
			}

			wp_delete_post($productId, true);
		}
	}

	/**
	 * Briše sve kategorije proizvoda.
	 */
	protected function deleteCategories()
	{
		$this->deleteTaxonomy('product_cat');
		delete_option('product_cat_children');
	}

	protected function deleteTaxonomy(string $taxonomy)
	{
		global $wpdb;

		$sql = sprintf("SELECT `term_id` FROM `{$wpdb->prefix}term_taxonomy` WHERE `taxonomy` = '%s'", $taxonomy);
		$categoryIds = $wpdb->get_col($sql, 0);

		foreach ($categoryIds as $categoryId) {
			$categoryId = intval($categoryId);

			if ($imageId = get_term_meta($categoryId, 'thumbnail_id', true)) {
				wp_delete_attachment($imageId, true);
			}

			wp_delete_term($categoryId, $taxonomy);
		}
	}
}