<?php
namespace Ep\WordPress\Service;
use PHPMailer;
use Zend\Stdlib\ArrayUtils;

/**
 * Class MailService
 *
 * @package Ep\WordPress\Service
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-webshop
 */
class MailService extends AbstractWordPressService
{
	/** @var array */
	protected $config;

	protected $defaultConfig = [
		'enabled' => '0',
		'host' => null,
		'port' => null,
		'username' => '',
		'password' => '',
	];

	/**
	 * Vraća konfiguraciju ovog servisa.
	 *
	 * @param null $key
	 *
	 * @return array
	 */
	protected function getConfig($key = null)
	{
		if (null === $this->config) {
			$this->config = ArrayUtils::merge(
				$this->defaultConfig,
				get_option('ep_smtp', [])
			);
		}

		return $this->config;
	}

	/**
	 * Kačimo se na WordPress.
	 */
	public function attach(): void
	{
		$config = $this->getConfig();

		if ('1' === $config['enabled']) {
			add_action('phpmailer_init', [$this, 'configurePhpMailer']);
		}
	}

	/**
	 * Ako je postavljen SMTP, konfiguriramo PHPMailer da šalje tako mailove onda.
	 *
	 * @param PHPMailer $mailer
	 */
	public function configurePhpMailer(PHPMailer $mailer)
	{
		$config = $this->getConfig();

		if ('1' === $config['enabled']) {
			$mailer->isSMTP();
			$mailer->SMTPAuth = true;
			$mailer->Host = $config['host'] ?? null;
			$mailer->Port = $config['port'] ?? 25;
			$mailer->Username = $config['username'] ?? null;
			$mailer->Password = $config['password'] ?? null;
		}
	}
}